[OE-core] [PATCH] oeqa/selftest: Added 2 testcases and updated setup for other two in imagefeatures.

Daniel Istrate daniel.alexandrux.istrate at intel.com
Tue Jul 7 11:36:58 UTC 2015


Automated 2 oe-selftest testcases:
- 1116: Check if clutter image can be built
- 1117: Check Wayland support in image

Updated setup for test_efi_gummiboot_images_can_be_build and
test_wic_command_can_create_efi_gummiboot_installation_images
to accomodate latest wic changes.

Signed-off-by: Daniel Istrate <daniel.alexandrux.istrate at intel.com>
---
 meta/lib/oeqa/selftest/imagefeatures.py | 41 +++++++++++++++++++++++++++++++--
 1 file changed, 39 insertions(+), 2 deletions(-)

diff --git a/meta/lib/oeqa/selftest/imagefeatures.py b/meta/lib/oeqa/selftest/imagefeatures.py
index e49f498..e0e424d 100644
--- a/meta/lib/oeqa/selftest/imagefeatures.py
+++ b/meta/lib/oeqa/selftest/imagefeatures.py
@@ -207,6 +207,41 @@ class ImageFeatures(oeSelfTest):
         system('pkill qemu')
         proc_qemu.close()
 
+    @testcase(1116)
+    def test_clutter_image_can_be_built(self):
+        """
+        Summary:     Check if clutter image can be built
+        Expected:    1. core-image-clutter can be built
+        Product:     oe-core
+        Author:      Ionut Chisanovici <ionutx.chisanovici at intel.com>
+        AutomatedBy: Daniel Istrate <daniel.alexandrux.istrate at intel.com>
+        """
+
+        # Build a core-image-clutter
+        ret = bitbake('core-image-clutter')
+        self.assertEqual(0, ret.status, 'Failed to build core-image-clutter')
+
+    @testcase(1117)
+    def test_wayland_support_in_image(self):
+        """
+        Summary:     Check Wayland support in image
+        Expected:    1. Wayland image can be build
+                     2. Wayland feature can be installed
+        Product:     oe-core
+        Author:      Ionut Chisanovici <ionutx.chisanovici at intel.com>
+        AutomatedBy: Daniel Istrate <daniel.alexandrux.istrate at intel.com>
+        """
+
+        features = 'DISTRO_FEATURES_append = " wayland"\n'
+        features += 'CORE_IMAGE_EXTRA_INSTALL += "wayland weston"'
+
+        # Append 'features' to local.conf
+        self.append_config(features)
+
+        # Build a core-image-weston
+        ret = bitbake('core-image-weston')
+        self.assertEqual(0, ret.status, 'Failed to build a core-image-weston')
+
 
 class Gummiboot(oeSelfTest):
 
@@ -240,8 +275,10 @@ class Gummiboot(oeSelfTest):
         features += 'MACHINE = "nuc"'
         self.append_config(features)
 
-        # Run "bitbake core-image-minimal" to build a nuc efi/gummiboot image
-        ret = bitbake('core-image-minimal')
+        # Run "bitbake syslinux syslinux-native parted-native dosfstools-native mtools-native core-image-minimal "
+        # to build a nuc/efi gummiboot image
+
+        ret = bitbake('syslinux syslinux-native parted-native dosfstools-native mtools-native core-image-minimal')
         self.assertEqual(0, ret.status, 'Failed to build a core-image-minimal')
 
     @testcase(1101)
-- 
2.1.4




More information about the Openembedded-core mailing list